#
# spec file for package golang-github-linuxdeepin-go-x11-client
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define   provider        github
%define   provider_tld    com
%define   project         linuxdeepin
%define   repo            go-x11-client
# https://github.com/linuxdeepin/go-x11-client
%define   provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%define   import_path     %{provider_prefix}
# %define   commit          a10a839c0f79ea80d2b4309c6f2d120f98664c5a
# %define   shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           deepin-x11-client
Version:        0.6.9
Release:        1.18
Summary:        A X11 client Go bindings
License:        GPL-3.0+
URL:            https://github.com/linuxdeepin/go-x11-client
Source0:        https://github.com/linuxdeepin/go-x11-client/archive/%{version}/%{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Group:          Development/Languages/Golang
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  libpulse0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pam-devel
BuildRequires:  fdupes
BuildRequires:  mobile-broadband-provider-info
BuildRequires:  golang-packaging
BuildRequires:  golang-github-linuxdeepin-go-lib
AutoReqProv:    Off
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{go_provides}
%{go_exclusivearch}

%description
it is a X11 protocol go language binding.

%package -n golang-%{provider}-%{project}-%{repo}
Summary:        Additional golang-github-linuxdeepin-go-x11-client libraries
Group:          Development/Languages/Golang
AutoReqProv:    On
Autoreq:        Off
Requires:       golang-github-linuxdeepin-go-lib
BuildArch:      noarch

%description -n golang-%{provider}-%{project}-%{repo}
This package contains additional golang-github-linuxdeepin-go-x11-client
libraries that are developed by the Go team but outside of the main source tree.

%prep
%setup -q -a1 -n %{repo}-%{version}

%build
export GO111MODULE=off
%goprep %{import_path}
%gobuild ...

%install
%goinstall
%gosrc
%gofilelist

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/*

%files -n golang-%{provider}-%{project}-%{repo} -f file.lst
%defattr(-,root,root)
%doc README
%license LICENSE

%changelog
* Sat Apr  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.6.9
  * Change pkg.deepin.io to github.com
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Use last stable version of go to build
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Leap 15.4+
* Fri May 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Keep golang verion on 1.15 on Tumbleweed, the project does not support
  golang 1.16+
* Mon Feb 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.6.3
  * add print_gopath in Makefile
  * feat(util/keysyms): add keysym to visible char map
  * fix(randr): GetPreferredMode panic
  * feat(xproto): add ChangeHosts
* Thu Apr 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.4.1
  * feat: add util xcursor
  * fix: build failed
* Sun Mar 10 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 0.3.0
  * chore: use WriteBool and ReadBool
  * feat: xkb add more functions
  * chore: exts use new reader
  * chore: xproto event use new reader
  * feat: implement new Reader
  * feat: add ext xkb
  * feat: delete other error types, leaving only the Error type
  * chore: continue to replace uint64 with SeqNum
  * feat: use special seqNum to indicate error
  * fix: requestCheck do not unlock c.ioMu before return
  * chore: replace uint64 with SeqNum
  * feat: reduce memory usage for encoding requests
  * fix: requestCheck method
  * feat: add ext shm
  * feat: add ext render
  * feat: support ge generic event
  * feat: add ext input
  * fix: readMapNotifyEvent no set Window field
  * fix: conn read blocked when event chan full
  * feat(ext/randr): add more events
  * fix(ext/randr): name typo
  * feat: add ext xfixes
  * fead: handle conn read write error
  * feat: Conn add method IDUsedCount
  * fix: wrong call NewError
  * feat: add resource id allocator
  * feat: conn add atom cache
  * fix: ewmh _NET_SUPPORTING_WM_CHECK is not root property
  * feat: add ext randr
  * feat: add ext dpms and screensaver
  * chore: call log.Print if env DEBUG_X11_CLIENT = 1
  * chore(deb): set env DH_GOLANG_EXCLUDES
  * feat: handwriting encode decode part
  * fix: atom WM_CHANGE_STATE not found
  * fix(wm/ewmh): get icon failed
  * feat: add WriteSelectionNotifyEvent
  * chore: add makefile for sw_64
  * fix: readSetup
* Sun Apr  8 2018 hillwood@opensuse.org
- Update version to 0.0.2
  * Remove usr/bin
  * Expand event chan buffer size
  * Fix: Adapt lintian
* Thu Nov  9 2017 hillwood@opensuse.org
- Change buildarch to noarch.
* Wed Nov  8 2017 hillwood@opensuse.org
- Cleanup spec.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
